@@ -13,6 +13,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KUrlRequester>
+#include <kio_version.h>
 
 #include <QCheckBox>
 #include <QComboBox>
@@ -96,7 +97,14 @@ KGpgFirstAssistant::KGpgFirstAssistant(QWidget *parent)
 	gridLayout->addWidget(txtGpgVersion, 3, 1, 1, 1);
 
 	binURL = new KUrlRequester(page);
-	binURL->setFilter(i18nc("search filter for gpg binary", "gpg|GnuPG binary\n*|All files"));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 108, 0)
+	binURL->setNameFilters({
+	    i18nc("search filter name for gpg binary", "GnuPG binary") + QLatin1String(" (gpg)"),
+	    i18n("All files") + QLatin1String(" (*)"),
+	});
+#else
+	binURL->setFilter(QLatin1String("gpg|") + i18nc("search filter name for gpg binary", "GnuPG binary") + QLatin1String("\n*|")+ i18n("All files"));
+#endif
 	QString gpgBin = QStandardPaths::findExecutable(QLatin1String("gpg2"));
 	if (gpgBin.isEmpty())
 		gpgBin = QStandardPaths::findExecutable(QLatin1String("gpg"));
