@@ -48,11 +48,7 @@ kgpgOptions::kgpgOptions(QWidget *parent, KGpgItemModel *model)
 	   m_page6(new ServerConf()),
 	   m_page7(new MiscConf()),
 	   m_serverModel(new GpgServerModel(m_page6)),
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 86, 0)
 	   m_fontchooser(new KFontChooser(KFontChooser::NoDisplayFlags, m_page3->tabWidget3->widget(1))),
-#else
-	   m_fontchooser(new KFontChooser(m_page3->tabWidget3->widget(1), KFontChooser::NoDisplayFlags, QStringList())),
-#endif
 	   m_model(model),
 	   m_combomodel(new KeyListProxyModel(this, KeyListProxyModel::SingleColumnIdFirst))
 {
@@ -64,11 +60,10 @@ kgpgOptions::kgpgOptions(QWidget *parent, KGpgItemModel *model)
 	m_combomodel->sort(0);
 
 	// Initialize the default server and the default server list.
-	defaultKeyServer = QLatin1String("hkp://pool.sks-keyservers.net");
+	defaultKeyServer = QLatin1String("hkp://keyserver.ubuntu.com");
 	defaultServerList << defaultKeyServer
+			<< QLatin1String("hkp://keys.openpgp.org")
 			<< QLatin1String("hkp://subkeys.pgp.net")
-			<< QLatin1String("hkp://search.keyserver.net")
-			<< QLatin1String("hkp://pgp.dtype.org")
 			<< QLatin1String("hkp://wwwkeys.pgp.net");
 
 	// Read the default keyserver from the GnuPG settings.
@@ -176,7 +171,7 @@ void kgpgOptions::slotChangeHome()
 				confPath = QLatin1String( "gpg.conf" );
 				QFile confFile(gpgHome + confPath);
 				if (!confFile.open(QIODevice::WriteOnly)) {
-					KMessageBox::sorry(this, i18n("Cannot create configuration file. Please check if destination media is mounted and if you have write access."));
+					KMessageBox::error(this, i18n("Cannot create configuration file. Please check if destination media is mounted and if you have write access."));
 					return;
 				} else {
 					QTextStream stream(&confFile);
@@ -199,12 +194,12 @@ bool kgpgOptions::isValidKeyserver(const QString &server)
 		return false;
 
 	if (server.contains(QLatin1Char( ' ' ))) {
-		KMessageBox::sorry(this, i18n("Key server URLs may not contain whitespace."));
+		KMessageBox::error(this, i18n("Key server URLs may not contain whitespace."));
 		return false;
 	}
 
 	if (serverList.contains(server)) {
-		KMessageBox::sorry(this, i18n("Key server already in the list."));
+		KMessageBox::error(this, i18n("Key server already in the list."));
 		return false;
 	}
 
